import 'dart:io';
import 'package:path/path.dart';
import 'package:process_run/process_run.dart';
import 'package:yaml/yaml.dart';
import 'package:yuro_cli/core/core.dart';

class YamlUtil {
  YamlUtil._();

  static Future<String> getNativeVersion() async {
    var lockFile = File(join(rootPath, 'pubspec.lock'));
    var exists = await lockFile.exists();
    if (!exists) throw FileSystemException('file not exists! ${lockFile.path}');
    var yamlMap = loadYaml(lockFile.readAsStringSync()) as YamlMap;
    if (yamlMap['packages']['yuro_cli'] == null) {
      Logger.e('can not find this package which name is yuro_cli');
      return null;
    } else {
      return yamlMap['packages']['yuro_cli']['version'].toString();
    }
  }

  static Future<bool> registerAssets(String path) async {
    var yamlFile = File(join(rootPath, 'pubspec.yaml'));
    var yamlMap = loadYaml(yamlFile.readAsStringSync()) as YamlMap;
    if (!yamlMap.containsKey('flutter')) {
      yamlFile.writeAsStringSync('\rflutter:', mode: FileMode.append, flush: true);
      yamlMap = loadYaml(yamlFile.readAsStringSync()) as YamlMap;
    }
    var flutter = yamlMap['flutter'] as YamlMap;
    if (flutter == null || !flutter.containsKey('assets')) {
      yamlFile.writeAsStringSync('\r  assets:', mode: FileMode.append, flush: true);
      yamlMap = loadYaml(yamlFile.readAsStringSync()) as YamlMap;
    }
    var assets = flutter['assets'] as YamlList;
    if (assets == null || !assets.contains(path)) {
      yamlFile.writeAsStringSync('\r    - $path', mode: FileMode.append, flush: true);
    }
    var res = await run('flutter', ['pub', 'get']);
    if (res.exitCode != 0) {
      throw Exception(res.stderr);
    }
    return true;
  }
}
